FEATURES_SWAP_IF_A_GREATER_THAN_B, 	//bool
FEATURES_SAVEPREFSONEXIT, 	//bool
FEATURES_IGNORESAVEDMARKERS, 	//bool
FEATURES_USE_ODML, 	//bool
FEATURES_USE_SYSTRAY, 	//bool
FEATURES_REUSE_2PASS_LOG, 	//bool
FEATURES_AUDIOBAR_USES_MASTER, 	//bool
FEATURES_THREADING_LAVC, 	//uint32_t
FEATURES_CPU_CAPS, 	//uint32_t
FEATURES_MPEG_NO_LIMIT, 	//bool
FEATURES_ALTERNATE_MP3_TAG, 	//bool
FEATURES_VDPAU, 	//bool
FEATURES_XVBA, 	//bool
FEATURES_LIBVA, 	//bool
FEATURES_ENABLE_OPENGL, 	//bool
FEATURES_CAP_REFRESH_ENABLED, 	//bool
FEATURES_CAP_REFRESH_VALUE, 	//uint32_t
FEATURES_SDLDRIVER, 	//string
LASTFILES_LASTDIR_READ, 	//string
LASTFILES_LASTDIR_WRITE, 	//string
LASTFILES_FILE1, 	//string
LASTFILES_FILE2, 	//string
LASTFILES_FILE3, 	//string
LASTFILES_FILE4, 	//string
LASTPROJECTS_LASTDIR_READ, 	//string
LASTPROJECTS_LASTDIR_WRITE, 	//string
LASTPROJECTS_FILE1, 	//string
LASTPROJECTS_FILE2, 	//string
LASTPROJECTS_FILE3, 	//string
LASTPROJECTS_FILE4, 	//string
MESSAGE_LEVEL, 	//uint32_t
AUDIO_DEVICE_AUDIODEVICE, 	//string
AUDIO_DEVICE_ALSA_DEVICE, 	//string
VIDEODEVICE, 	//uint32_t
PRIORITY_ENCODING, 	//uint32_t
PRIORITY_INDEXING, 	//uint32_t
PRIORITY_PLAYBACK, 	//uint32_t
DEFAULT_POSTPROC_TYPE, 	//uint32_t
DEFAULT_POSTPROC_VALUE, 	//uint32_t
DEFAULT_DOWNMIXING, 	//uint32_t
DEFAULT_LANGUAGE, 	//string
DEFAULT_WARN_FOR_FONTS, 	//bool
MPEGSPLIT_AUTOSPLIT, 	//uint32_t
AVISYNTH_AVISYNTH_ALWAYS_ASK, 	//bool
AVISYNTH_AVISYNTH_DEFAULTPORT, 	//uint32_t
AVISYNTH_AVISYNTH_LOCALPORT, 	//uint32_t
